===============================
Zeus Python Client
===============================

.. image:: https://magnum.travis-ci.com/CiscoZeus/python-zeusclient.svg?token=Ehc2A9GF6FzDURskVXsm&branch=master
    :target: https://magnum.travis-ci.com/CiscoZeus/python-zeusclient
.. image:: https://img.shields.io/pypi/v/cisco-zeus.svg
        :target: https://pypi.python.org/pypi/cisco-zeus


Python client for CiscoZeus.io. It allows a user to send and receive data to and from Zeus.

* Free software: Apache License
* Documentation: https://cisco-zeus.readthedocs.org.

Features
--------

* Send logs and metrics to Zeus
* Query both logs and metrics
